import numpy as np
from matplotlib import image


def make_label_meta(label_path, out_path, n_max):
    """
    label_path: Path to label txt file.
    out_path: Where to store the file with the subset.
    n_max: How many lines to extract.
    """
    with open(label_path) as all_labels, open(out_path, mode="w") as metadata:
        n = 0
        for line in all_labels:
            metadata.write(line)
            n += 1
            if n == n_max:
                break


def make_sprite(imgs, out_path):
    """
    imgs: 2D (!) numpy array containing MNIST image data (i.e. 784-length vectors).
    out_path: Path to store sprite image at (e.g. path/to/file.png).
    """
    imgs_square = imgs.reshape(-1, 28, 28)
    grid_dim = int(np.ceil(np.sqrt(len(imgs))))
    grid_rows = [np.concatenate(imgs_square[ind:(ind+grid_dim)], axis=1) for ind in range(0, len(imgs), grid_dim)]
    # maybe pad last row
    missing = grid_rows[0].shape[1] - grid_rows[-1].shape[1]
    if missing:
        grid_rows[-1] = np.pad(grid_rows[-1], ((0, 0), (0, missing)), mode="constant")
    grid = np.concatenate(grid_rows, axis=0)
    # note that the images are reversed (black on white background) for readability
    image.imsave(out_path, grid, cmap="Greys")
